#
# spec file for package librecad
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           librecad
Version:        2.2.0.2
Release:        1.3
Summary:        Computer-aided design (CAD) software package for 2D design and drafting
License:        (Apache-2.0 OR SUSE-GPL-3.0+-with-font-exception) AND GPL-2.0-only
Group:          Productivity/Graphics/CAD
URL:            http://librecad.org/

#Git-Web:       https://github.com/LibreCAD/LibreCAD
Source:         https://github.com/LibreCAD/LibreCAD/archive/%version.tar.gz
# Version is actually 8, not 3 (it is 3 in the filename due to how MediaWiki
# works -- see http://wiki.librecad.org/index.php/File:Architect3-LCAD.zip)
Source2:        https://wiki.librecad.org/images/d/d9/Architect3-LCAD.zip
Source3:        https://wiki.librecad.org/images/7/70/Electronics3-LCAD.zip
Source4:        https://wiki.librecad.org/images/9/9d/Electrical1-LCAD.zip
Source10:       ttf2lff.1
Source20:       %name-rpmlintrc
Patch4:         librecad-no-date.diff
Patch5:         librecad-use-system-libdxfrw.patch
Patch6:         librecad-install.diff
Patch7:         librecad-plugindir.diff
BuildRequires:  fdupes
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++ >= 4.7
BuildRequires:  libboost_headers-devel
BuildRequires:  muparser-devel
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRequires:  wqy-microhei-fonts
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(libdxfrw) >= 1
Requires(post): desktop-file-utils
Requires(post): shared-mime-info
Requires(postun):desktop-file-utils
Requires(postun):shared-mime-info
Recommends:     %name-parts

%description
LibreCAD is a Qt Computer-aided design (CAD) software package for 2D design
and drafting.

%package parts
Summary:        Parts collection for LibreCAD
Group:          Productivity/Graphics/CAD
Requires:       %name
BuildArch:      noarch

%description parts
Collection of parts for LibreCAD, a Qt application to design 2D
CAD drawings.

%prep
%setup -qn LibreCAD-%version -a2 -a3 -a4
%autopatch -p1

pc="libdxfrw"
if ! pkg-config --exists "$pc"; then
	pc=libdxfrw0
fi
dxfrw_includedir=$(pkg-config --cflags-only-I "$pc" | sed 's|-I||g')

# Fix paths
sed -i 's|##LIBDIR##|%_libdir|g' librecad/src/lib/engine/rs_system.cpp
sed -i 's|$${DXFRW_INCLUDEDIR}|'"$dxfrw_includedir"'|g' librecad/src/src.pro
sed -i 's@LRELEASE="lrelease"@LRELEASE="lrelease-qt5"@' scripts/postprocess-unix.sh

# Make sure bundled libraries are not used
rm -rf libraries/libdxfrw

# Fix "wrong-file-end-of-line-encoding" rpmlint warning
sed -i 's/\r$//' licenses/{MIT,KST32B_v2,lc_opengost-fonts}.txt

%build
echo 'DISABLE_POSTSCRIPT = true' > librecad/src/custom.pri
qmake-qt5 \
librecad.pro CONFIG+="release" \
	QMAKE_CFLAGS+="%optflags" QMAKE_CXXFLAGS+="%optflags"
make %{?_smp_mflags}
rm -f unix/resources/fonts/wqy-unicode.lff
mkdir -p unix/resources/fonts
./unix/ttf2lff -L "Apache-2.0 or SUSE-GPL-3.0+-with-font-exception" \
	"%_datadir/fonts/truetype/wqy-microhei.ttc" \
	unix/resources/fonts/wqy-unicode.lff

%install
b="%buildroot"
# No make install :(
export BUILDDIR="$b/%_datadir/%name"
sh scripts/postprocess-unix.sh

install -Dpm0755 "unix/%name" "$b/%_bindir/%name"
install -Dpm0755 "unix/ttf2lff" "$b/%_bindir/ttf2lff"
install -Dpm0644 "desktop/%name.1" "$b/%_mandir/man1/%name.1"
p="$b/%_libdir/%name/plugins"
mkdir -p "$p"
install -Dpm0755 unix/resources/plugins/* "$p/"
cat desktop/librecad.desktop
perl -i -lpe 's{(MimeType=.*?);+$}{$1}' desktop/librecad.desktop
cat desktop/librecad.desktop
install -Dpm0644 "desktop/%name.desktop" "$b/%_datadir/applications/%name.desktop"
install -Dpm0644 "librecad/res/main/%name.png" "$b/%_datadir/pixmaps/%name.png"
install -Dpm0644 "desktop/%name.sharedmimeinfo" "$b/%_datadir/mime/packages/%name.xml"
install -Dpm0644 "%_sourcedir/ttf2lff.1" "$b/%_mandir/man1/"

install -d "$b/%_datadir/%name/library/architecture" \
	"$b/%_datadir/%name/library/electronics" \
	"$b/%_datadir/%name/library/electrical"
cp -a Architect8-LCAD "$b/%_datadir/%name/library/architecture/"
cp -a Electronic8-LCAD "$b/%_datadir/%name/library/electronics/"
cp -a Electrical1-LCAD "$b/%_datadir/%name/library/electrical/"

%suse_update_desktop_file -G "CAD Program" -r %name Graphics 2DGraphics VectorGraphics
# Fix rpmlint warning "invalid-desktopfile"
perl -pi -e "s|image/vnd.dxf|image/vnd.dxf;|" %buildroot%_datadir/applications/librecad.desktop

%fdupes -s %buildroot/%_prefix

%if 0%{?suse_version} && 0%{?suse_version} < 1550
%post
%mime_database_post
%desktop_database_post

%postun
%mime_database_postun
%desktop_database_postun
%endif

%files
%doc README.md
%license LICENSE licenses/*txt
%_bindir/librecad
%_bindir/ttf2lff
%_libdir/%name
%_mandir/man1/librecad.1*
%_mandir/man1/ttf2lff.1*
%_datadir/applications/librecad.desktop
%_datadir/mime/packages/%name.xml
%_datadir/pixmaps/librecad.png
%dir %_datadir/%name
%_datadir/%name/fonts
%_datadir/%name/patterns
%_datadir/%name/qm

%files parts
%dir %_datadir/%name
%_datadir/%name/library

%changelog
* Mon Sep  4 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to release 2.2.0.2:
  * fixes an undetected vulnerability when opening malformed LFF
    font files that caused a crash
  * fixes format issues in bundled fonts
  * fixes regression, finding nearest points on ellipses caused a crash
  * plugin Importshp has been removed
- Drop librecad-use-system-shapelib.patch since the plugin has been
  removed.
- Rebase patches.
* Sun Feb 19 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.2.0 [boo#1208447]
  * many causes of crashes have been eliminated
  * eliminated DWG issues in libdxfrw, which caused several crashes
  * the performance of panning and zooming in large files has
    been significantly improved
  * the undo/redo engine has been completely revised due to
    several problems
  * adjustments for new compiler and Qt versions were required
  * extension of the command line, multi-line commands, paste and
    open command files
  * improvement of the print preview, with tiled printing and
    line widths adjustment
  * multiple selection and bulk actions in block and layer lists
* Mon Jul 11 2022 Dirk Müller <dmueller@suse.com>
- update to 2.2.0 rc4:
  * symbols to unicode.lff
  * new error code from libdxfrw update
  * build Windows, MacOS and Linux packages in one action
  * added tool tips to Categories tool widget (#1519)
  * added @ symbol to relative coordinates in status bar (#1452)
  * changed misleading unit label in curent drawing preferences (#1453)
  * changed tab order in text dialog (#1432)
  * maximum size of status bar for hidpi displays
  * sync libdxfrw (072aecd)
  * copy/rename media files in desktop folder to remove whitespaces
  * fixed renaming of nested blocks (#1527)
  * preserve list position in block and layer list (#1515)
  * fixed polyline issue when line type was changed (#1496)
  * add minutes label to auto save time in application preferences (#1412)
  * add files saved as with new name to recent files (#1364)
  * snap on middle point failed for spline through points (#1395)
  * spline issue with tolerance on ascii to double conversion
  * DXF viewport reading issue by updating libdxfrw
  * status bar height toggling on auto save
  * solid fill hatch issues
  * Ukrainian and symbol characters in unicode.lff
  * possible out of bounds read with MText entities
  * AppImage was broken by fix for (#1488)
  * wrong translations folder for additionals paths from settings
  * getDirectoryList() failed on Linux when librecad is in $PATH (#1488)
  * bounds check in LWPolyline
  * NULL check for hatch code 93
  * vulnerabilities in JWW parser
- drop 0001-Added-bounds-checking-to-CDataMoji-in-jww-parser.patch,
  0001-Added-bounds-check-to-CDataList-in-JWW-parser.patch
  0001-fixed-1488-getDirectoryList-failed-on-Linux-when-lib.patch: upstream
* Mon May 16 2022 Jan Engelhardt <jengelh@inai.de>
- Add 0001-Added-bounds-checking-to-CDataMoji-in-jww-parser.patch
  [boo#1195105] [CVE-2021-45341]
- Add 0001-Added-bounds-check-to-CDataList-in-JWW-parser.patch
  [boo#1195122] [CVE-2021-45342]
* Wed May  4 2022 Marcus Meissner <meissner@suse.com>
- switch source urls to https
* Wed Mar 30 2022 Jan Engelhardt <jengelh@inai.de>
- Strip excess blank fields from librecad.desktop:MimeType
  [boo#1197664]
* Sun Jan 23 2022 Jan Engelhardt <jengelh@inai.de>
- Replace "qt4" in description, the build does not use Qt4 anymore.
* Thu Jan  6 2022 Jiri Slaby <jslaby@suse.cz>
- replace the revert by an upstream fix
  * add 0001-fixed-1488-getDirectoryList-failed-on-Linux-when-lib.patch
  * remove
    0001-Revert-AppImage-build-on-GitHub-Actions-with-go-appi.patch
    0002-Revert-RS_System-getDirectoryList-add-plugins-folder.patch
    0003-Revert-fix-RS_System-getDirectoryList-use-relative-p.patch
* Sat Jan  1 2022 Jiri Slaby <jslaby@suse.cz>
- fix paths creation (e.g. fonts loading) by:
  * 0001-Revert-AppImage-build-on-GitHub-Actions-with-go-appi.patch
  * 0002-Revert-RS_System-getDirectoryList-add-plugins-folder.patch
  * 0003-Revert-fix-RS_System-getDirectoryList-use-relative-p.patch
  (did the revert and waiting for the upstream fix)
* Mon Dec 20 2021 Jiri Slaby <jslaby@suse.cz>
- update to 2.2.0-rc3
  * major release
  * DWG imports are more reliable now
  * and a lot more of bugfixes and improvements
- remove (they are in upstream now)
  * 0001-fix-build-with-gcc-9.patch
  * add-boost-tuple-include-to-fix-build.patch
  * ensured-all-objects-are-shown-when-a-layer-is-toggle.patch
  * fix-build-with-Qt-5.11.patch
  * fix-build-with-Qt-5.15.patch
- remove qcad provides/obsoletes -- it's an ancient history
* Tue May  4 2021 Jiri Slaby <jslaby@suse.cz>
- add add-boost-tuple-include-to-fix-build.patch
* Sun Jun  7 2020 Jan Engelhardt <jengelh@inai.de>
- Add fix-build-with-Qt-5.15.patch. Set CFLAGS+=-fcommon.
* Tue May 28 2019 Jiri Slaby <jslaby@suse.com>
- add 0001-fix-build-with-gcc-9.patch
* Mon Jun 11 2018 jslaby@suse.com
- add fix-build-with-Qt-5.11.patch
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sat Oct  8 2016 jslaby@suse.com
- add: ensured-all-objects-are-shown-when-a-layer-is-toggle.patch
  (from upstream)
* Tue Sep 27 2016 jengelh@inai.de
- Update to new upstream release 2.1.3
  * The Shift key had no effect and would not activate the
  command line.
* Mon Sep 19 2016 jslaby@suse.com
- Update to new upstream release 2.1.2
  * wouldn't build with gcc 5.4 and 6
  * mouse cursor was missing for 'Arc Tangential'
  * right-click with plugins could cause a crash
  * construction lines were not drawn when the line segment was out of view
  * DXF files with comments were not properly loaded
  * drawings were not marked as modified after an 'undo'
  * the command line didn't accept numpad input
  * the command widget didn't activate properly when floating
- librecad-gcc6.patch: Remove (unneeded now)
* Tue Jun 28 2016 jengelh@inai.de
- Update to new upstream release 2.1.1
  * Bugfixes:
  * draft mode was not set for new/opened drawings
  * performance did not improve when zooming into an area
  * certain polylines were not rendered properly
  * opening a file didn't restore the layer's construction state
  * the cursor was hidden for 'polyline from existing'
  * closing an inactive tab cleared the layer list
* Fri Jun 17 2016 jslaby@suse.com
- add librecad-gcc6.patch
* Tue Jun  7 2016 jslaby@suse.com
- Update to new upstream release 2.1.0
  * new features
  * lot of bug fixes
  * other changes
  * see full changelog at:
    https://github.com/LibreCAD/ChangeLogs/blob/master/developers/r-a-v-a-s/2-1/2-1-0/2-1-0.md
* Tue May 24 2016 jengelh@inai.de
- Update to new upstream release 2.0.11
  * Updated translations. Added non-uniform knots support.
  * Added Edit - Device Options.
  * Eliminated crash on save when auto backup is off.
  * Eliminated invalid bounding boxes from auto zoom.
* Mon May 16 2016 jslaby@suse.com
- Update to new upstream release 2.0.10:
  * the Arch paper sizes were not properly supported
  * the pen toolbar was wider than necessary on super HD displays
  * various memory leaks
  * build error when using boost version greater than 1.53
  * auto-save could not really be turned off
  * file dialog always opened with DXF, instead of the last chosen file type
  * the statusbar and statusbar font were not allowed to autosize
  * the fixed extension line length option was not working for dimensions
  * the program would crash after: modify action -> undo -> repeat modify
    action
* Mon Jan 18 2016 jslaby@suse.com
- Update to new upstream release 2.0.9:
  * Mostly a bug fixing release
  * Fixed a few crashes due to undo and deleted entities
  * More at:
    http://forum.librecad.org/2-0-9-released-td5712809.html
* Wed Sep  9 2015 asterios.dramis@gmail.com
- Update to new upstream release 2.0.8:
  * DWG read support.
  * SVG export support.
  * Arabic Language GUI support. More work is needed for:
    Right-to-left support for Text entities.
    Arabic fonts for Text.
  * More user configurable settings in App Preferences.
  * Many fixes and enhancements, see:
    http://forum.librecad.org/2-0-8-released-td5712049.html
    for details.
- Added new Part Library:
  Electrical1-LCAD.zip
- Rebased librecad-install.diff, librecad-no-date.diff and
  librecad-use-system-libdxfrw.patch to apply cleanly.
- Added a patch "librecad-use-system-shapelib.patch" to use the
  system shapelib instead of the bundled one and new build
  requirement libshp-devel (for openSUSE > 13.2).
- Update includes the fix for boo#937874.
* Thu Apr 30 2015 crrodriguez@opensuse.org
- Switch to QT5 for Factory builds.
* Sat Jan 31 2015 asterios.dramis@gmail.com
- Update to new upstream release 2.0.7:
  * A serious command line regression since 2.0.6 was fixed:
    keyboard Enter/Esc support, command line widget in a second
    screen, etc. Also fixed are some crashes for tangential circle
    drawing and polyline addition.
  * Improved LFF font support
  * The command line can be used as a calculator by typing math
    expression after command “cal”. For example, command "cal 1+1"
    to get output "2"
  * Many fixes and enhancements, see:
    http://blog.librecad.org/
    for details
  From version 2.0.5:
  * Interpolation spline. Draw->Spline->Spline Points.
  * File -> Export as PDF.
  * Korean language support.
  * Smooth scrolling/zooming
  * Work-in-progress, finding enclosed area within a contour.
  * “Modify->Round” renamed to “Modify->Fillet”.
  * Command line aliases can be made for both regular commands and
    short commands.
- Added new Part Libraries:
  Architect8-LCAD.zip and Electronics8-LCAD.zip.
- Added new build requirement unzip.
- Rebased librecad-install.diff and
  librecad-use-system-libdxfrw.patch to apply cleanly.
* Wed Aug 13 2014 asterios.dramis@gmail.com
- Update to new upstream release 2.0.4:
  * Windows and OS/X printer dialog fails to appear when running Qt5;
  * A patched version of muparser is used by default for OS/X and win32;
  * Update layer for selected entities when a layer is selected
  * Plotting/drawing mathematical equations by smallfix
  * Draw circle by 2 points and radius
  * PIC file importer by cgrzemba
  * Update layer for selected entities when a layer is selected by ajisaacs
  * Lots of shortcut fixes by thomas
  * Arc angle updates for negative z-axis by coryjc190
  * Drawing order regression in 2.0.3
- Rebased librecad-use-system-libdxfrw.patch to apply cleanly.
* Sun May  4 2014 asterios.dramis@gmail.com
- Update to new upstream release 2.0.2:
  * Some notable changes visible to users:
    + Reworked snapping system to allow simultaneous multiple snapping options;
    snapping of equidistant middle points;
    + Helping/scratch layer support. Straight lines are kept infinite and
    entities are skipped  in printout;
    + Isometric grids;
    + Architectural tick;
    + Support of new ellipse features missing in version 1.0, such as,
    intersection, middle point, arc length, and tangential direction;
    + Several new drawing features for line, circle, and ellipse;
    + Improved localization, translation for plugins and standard dialogs;
    + Support for a general factor for drawing size dimensions to help scaled
    drawings;
    + Revert entities direction, developed by effad;
    + Some UI tweaking;
    + Windows setup registration to add LC in Windows Control Panel ‘Programs
    and Features’.
  * LibreCAD-2.0 is using a new dxfrw library to handle the DXF file format,
    and some advantage of the dxfrw library brings are:
    + New dxf library supporting ascii and binary files, more versions and
    fully compatible with the specification;
    + Support of templates;
    + Dimensions: support for aligned / horizontal text;
    + Dimensions: added general scale property;
    + Added support for single line text.
  * Some internal changes since LibreCAD-1.0 series:
    + Removed Qt3 dependency;
    + Reworked methods to calculate intersections to simplify support for new
    entity types;
    + Improved many drawing algorithms for performance;
    + Added scripts to allow automatic building on OS/X and Windows;
    + Added boost and C++11 support ;
    + Various code review and bug fixes.
  * See http://blog.librecad.org/ for more details.
- Updated License to GPL-2.0 and (Apache-2.0 or
  SUSE-GPL-3.0+-with-font-exception).
- Added a man page (ttf2lff.1) for the ttf2lff program.
- Removed bash, dxflib-devel and libqt4-devel-doc build requirements (not
  needed anymore).
- Added new build requirements boost-devel, libdxfrw-devel and
  wqy-microhei-fonts.
- Added mime_database_post/mime_database_postun entries sice the package
  installs a mime file.
- Rebased librecad-no-date.diff to apply cleanly.
- Removed the following patches (not needed anymore):
  * librecad-dxflib25.diff
  * librecad-external-dxflib.diff
- Added the following patches (taken from Fedora):
  * librecad-use-system-libdxfrw.patch (Use system libdxfrw)
* Sun Jun 23 2013 asterios.dramis@gmail.com
- Update to new upstream release 1.0.3:
  * Bugfix release.
- Removed librecad.mime.desktop file (not needed since dxf is part
  of the shared-mime-info database). Removed also the respective
  update-mime-database post/postun entries.
- Added desktop_database_post/desktop_database_postun entries
  since the package defines a MIME handler.
* Sat May  5 2012 jengelh@medozas.de
- Update to new upstream release 1.0.2
  * replaces dependency on fparser library by
  license-compatible muparser
* Tue Oct 18 2011 jengelh@medozas.de
- Initial package for build.opensuse.org
